=== modified file 'Makefile.am'
--- Makefile.am	2012-01-02 12:40:15 +0000
+++ Makefile.am	2012-01-25 21:14:58 +0000
@@ -3,6 +3,10 @@
 pkgconfigdir = $(libdir)/pkgconfig
 pkgconfig_DATA = dee-1.0.pc
 
+if HAVE_ICU
+pkgconfig_DATA += dee-icu-1.0.pc
+endif
+
 if WANT_TESTS
 SUBDIRS += tests
 
@@ -17,6 +21,7 @@
 EXTRA_DIST = \
 	autogen.sh \
 	dee-1.0.pc.in \
+	dee-icu-1.0.pc.in \
 	COPYING.GPL
 
 DISTCHECK_CONFIGURE_FLAGS = --enable-gtk-doc --enable-introspection=no

=== modified file 'configure.ac'
--- configure.ac	2012-01-25 12:51:48 +0000
+++ configure.ac	2012-01-25 21:14:58 +0000
@@ -167,6 +167,7 @@
 		ICU_LIBS="$(icu-config --ldflags-libsonly)"
 		AC_SUBST(ICU_CFLAGS)
 		AC_SUBST(ICU_LIBS)
+		AC_OUTPUT([dee-icu-1.0.pc])
 	else
 		AC_MSG_ERROR([Dee ICU support requires ICU >= 4.8])
 	fi
@@ -190,7 +191,7 @@
   tools/Makefile
   examples/Makefile
   vapi/Makefile
-])
+]) 
 
 dnl Output the results
 AC_MSG_NOTICE([

=== added file 'dee-icu-1.0.pc.in'
--- dee-icu-1.0.pc.in	1970-01-01 00:00:00 +0000
+++ dee-icu-1.0.pc.in	2012-01-25 21:14:58 +0000
@@ -0,0 +1,11 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@
+
+Name: @PACKAGE_NAME@
+Description: Dee ICU integration
+Version: @VERSION@
+Libs: -L${libdir} -ldee-1.0
+Cflags: -I${includedir}/dee-1.0
+Requires: glib-2.0 gthread-2.0 gobject-2.0 gio-2.0 gio-unix-2.0

=== modified file 'doc/reference/dee-1.0/dee-1.0-docs.sgml'
--- doc/reference/dee-1.0/dee-1.0-docs.sgml	2012-01-10 07:43:54 +0000
+++ doc/reference/dee-1.0/dee-1.0-docs.sgml	2012-01-25 21:14:58 +0000
@@ -38,6 +38,7 @@
       <xi:include href="xml/dee-term-list.xml"/>
       <xi:include href="xml/dee-text-analyzer.xml"/>
       <xi:include href="xml/dee-tree-index.xml"/>
+      <xi:include href="xml/dee-icu.xml"/>
   </chapter>
 
   <chapter>

=== modified file 'src/dee-icu-term-filter.c'
--- src/dee-icu-term-filter.c	2012-01-25 20:15:24 +0000
+++ src/dee-icu-term-filter.c	2012-01-25 21:14:58 +0000
@@ -29,15 +29,21 @@
 
 #include "dee-icu.h"
 
-/*
-UChar* u_strFromUTF8Lenient 	( 	UChar *  	dest,
-		int32_t  	destCapacity,
-		int32_t *  	pDestLength,
-		const char *  	src,
-		int32_t  	srcLength,
-		UErrorCode *  	pErrorCode 
-	) 	
-*/
+/**
+ * SECTION:dee-icu
+ * @title: Dee ICU Extensions
+ * @short_description: A suite of #DeeTermFilter<!-- -->s based on ICU
+ * @include: dee-icu.h
+ *
+ * This module allows developers to easily construct powerful
+ * #DeeTermFilter<!-- -->s with ease. The filters leverage the ICU
+ * framework to provide world class transliteration features.
+ *
+ * The filters can be employed manually by calling dee_icu_term_filter_apply()
+ * or installed in a #DeeAnalyzer by calling dee_analyzer_add_term_filter()
+ * passing the term filter instance as the user data and
+ * dee_icu_term_filter_destroy() as the #GDestroyNotify.
+ */
 
 struct _DeeICUTermFilter {
   UTransliterator *transliterator;
@@ -73,6 +79,20 @@
   return u_string;
 }
 
+/**
+ * dee_icu_term_filter_new:
+ * @system_id: A system id for the transliterator to use.
+ *             See <link anchor="http://userguide.icu-project.org/transforms/general">userguide.icu-project.org/transforms/general</link>
+ * @rules: (allow-none): A set of transliteration rules to use.
+ *                       See <link anchor="http://userguide.icu-project.org/transforms/general/rules">userguide.icu-project.org/transforms/general/rules</link>
+ * @error: (allow-none): A place to return a #GError, or %NULL to ignore errors
+ *
+ * Create a new #DeeICUTermFilter for a given ICU transliterator system id
+ * and/or set of transliteration rules.
+ *
+ * Returns: (transfer full): A newly allocated #DeeICUTermFilter.
+ *                           Free with dee_icu_term_filter_destroy().
+ */
 DeeICUTermFilter*
 dee_icu_term_filter_new (const gchar *system_id,
                          const gchar  *rules,
@@ -110,16 +130,29 @@
   return self;
 }
 
-//#define DEFAULT_TRANSLITERATOR_RULES "Latin; Latin-ASCII; Lower; [^[:Letter:] [:Separator:]] Remove;"
-//#define DEFAULT_TRANSLITERATOR_RULES "Latin; Latin-ASCII;"
-
+/**
+ * dee_icu_term_filter_new_ascii_folder:
+ *
+ * Construct a term filter that folds any UTF-8 string into ASCII.
+ *
+ * Returns: (transfer full): A newly allocated #DeeICUTermFilter. Free with
+ *                           dee_icu_term_filter_destroy().
+ */
 DeeICUTermFilter*
 dee_icu_term_filter_new_ascii_folder ()
 {
-
   return dee_icu_term_filter_new ("Latin; Latin-ASCII;", NULL, NULL);
 }
 
+/**
+ * dee_icu_term_filter_apply:
+ * @self: The filter to apply
+ * @text: The text to apply the filter on
+ *
+ * Apply a #DeeICUTermFilter on a piece of UTF-8 text.
+ *
+ * Returns: (transfer full): A newly allocated string. Free with g_free().
+ */
 gchar*
 dee_icu_term_filter_apply (DeeICUTermFilter *self,
                            const gchar *text)
@@ -166,6 +199,12 @@
   return result;
 }
 
+/**
+ * dee_icu_term_filter_destroy:
+ * @filter: The filter to free
+ *
+ * Free all resources allocated by a #DeeICUTermFilter.
+ */
 void
 dee_icu_term_filter_destroy (DeeICUTermFilter *filter)
 {
@@ -175,3 +214,9 @@
 
   g_free (filter);
 }
+
+GQuark
+dee_icu_error_quark (void)
+{
+  return g_quark_from_static_string ("dee-icu-error-quark");
+}

=== modified file 'src/dee-icu.h'
--- src/dee-icu.h	2012-01-25 20:15:24 +0000
+++ src/dee-icu.h	2012-01-25 21:14:58 +0000
@@ -27,6 +27,26 @@
 
 G_BEGIN_DECLS
 
+/**
+ * DEE_ICU_ERROR:
+ *
+ * Error domain for the ICU extension to Dee. Error codes will be from the
+ * #DeeICUError enumeration
+ */
+#define DEE_ICU_ERROR dee_icu_error_quark()
+
+/**
+ * DeeICUError:
+ *
+ * Error codes for the ICU extension to Dee. These codes will be set when the
+ * error domain is #DEE_ICU_ERROR.
+ *
+ * @DEE_ICU_ERROR_PARSE_ERROR: Error parsing a transliteration rule or system id
+ */
+typedef enum {
+  DEE_ICU_ERROR_PARSE_ERROR
+} DeeICUError;
+
 typedef struct _DeeICUTermFilter DeeICUTermFilter;
 
 DeeICUTermFilter*        dee_icu_term_filter_new         (const gchar* system_id,

=== modified file 'vapi/dee-1.0.vapi'
--- vapi/dee-1.0.vapi	2012-01-25 20:15:24 +0000
+++ vapi/dee-1.0.vapi	2012-01-25 21:14:58 +0000
@@ -298,6 +298,11 @@
 		public string read (Dee.Model model, Dee.ModelIter iter);
 	}
 	[CCode (cheader_filename = "dee.h")]
+	public enum ICUError {
+		[CCode (cname = "DEE_ICU_ERROR_PARSE_ERROR")]
+		ICU_ERROR_PARSE_ERROR
+	}
+	[CCode (cheader_filename = "dee.h")]
 	[Flags]
 	public enum TermMatchFlag {
 		[CCode (cname = "DEE_TERM_MATCH_EXACT")]

